@@ -22,17 +22,15 @@
 #ifndef AUDACIOUS_VISUALIZATION_H
 #define AUDACIOUS_VISUALIZATION_H
 
-#include <glib.h>
-
 #include "plugins.h"
 
 void vis_send_clear (void);
-void vis_send_audio (const gfloat * data, gint channels);
+void vis_send_audio (const float * data, int channels);
 
 void vis_init (void);
 void vis_cleanup (void);
 
-gboolean vis_plugin_start (PluginHandle * plugin);
+bool_t vis_plugin_start (PluginHandle * plugin);
 void vis_plugin_stop (PluginHandle * plugin);
 
 PluginHandle * vis_plugin_by_widget (/* GtkWidget * */ void * widget);
