@@ -32,10 +32,8 @@
 #ifndef AUDTOOL_H
 #define AUDTOOL_H
 
-#include <mowgli.h>
 #include <audacious/dbus.h>
 
-extern mowgli_error_context_t *e;
 extern DBusGProxy *dbus_proxy;
 
 struct commandhandler {
@@ -43,12 +41,14 @@ struct commandhandler {
 	void (*handler)(gint argc, gchar **argv);
 	gchar *desc;
 	gint args;
-}; 
+};
 
 extern struct commandhandler handlers[];
 
 extern void audtool_report(const gchar *str, ...);
 extern void audtool_whine(const gchar *str, ...);
+extern void audtool_whine_args(const gchar *name, const gchar *str, ...);
+extern void audtool_whine_tuple_fields(void);
 
 extern void get_handlers_list(gint, gchar **);
 extern void get_current_song(gint, gchar **);
@@ -72,6 +72,8 @@ extern void set_volume(gint, gchar **);
 
 extern void playlist_position(gint, gchar **);
 extern void playlist_advance(gint, gchar **);
+extern void playlist_auto_advance_status(gint, gchar **);
+extern void playlist_auto_advance_toggle(gint, gchar **);
 extern void playlist_reverse(gint, gchar **);
 extern void playlist_length(gint, gchar **);
 extern void playlist_song(gint, gchar **);
@@ -89,10 +91,12 @@ extern void playlist_repeat_status(gint, gchar **);
 extern void playlist_repeat_toggle(gint, gchar **);
 extern void playlist_shuffle_status(gint, gchar **);
 extern void playlist_shuffle_toggle(gint, gchar **);
+void playlist_stop_after_status (gint argc, gchar * * argv);
+void playlist_stop_after_toggle (gint argc, gchar * * argv);
 extern void playlist_tuple_field_data(gint, gchar **argv);
-extern void playlist_show(gint, gchar **);
 extern void playlist_enqueue_to_temp(gint argc, gchar **argv);
 extern void playlist_ins_url_string(gint argc, gchar **argv);
+extern void playlist_title(gint, gchar **);
 
 extern void playqueue_add(gint, gchar **);
 extern void playqueue_remove(gint, gchar **);
@@ -121,7 +125,6 @@ extern void show_filebrowser(gint, gchar **);
 extern void shutdown_audacious_server(gint, gchar **);
 extern void show_about_window(gint, gchar **);
 
-extern void activate(gint argc, gchar **argv);
 extern void toggle_aot(gint argc, gchar **argv);
 extern void get_skin(gint argc, gchar **argv);
 extern void set_skin(gint argc, gchar **argv);
@@ -134,6 +137,7 @@ extern void equalizer_set_eq(gint argc, gchar **argv);
 extern void equalizer_set_eq_preamp(gint argc, gchar **argv);
 extern void equalizer_set_eq_band(gint argc, gchar **argv);
 extern void equalizer_active(gint argc, gchar **argv);
-extern void equalizer_show(gint, gchar **);
+
+extern gint check_args_playlist_pos(gint argc, gchar **argv);
 
 #endif
